CREATE TABLE Partit (
  id       			   number(10) 		CONsTRAINT NN_idPartit NOT NULL, 
  document 			   varchar2(20) 	CONSTRAINT NN_documentPartit NOT NULL CONSTRAINT UN_documentPartit UNIQUE, 
  nom      			   varchar2(50) 	CONSTRAINT NN_nomPartit NOT NULL, 
  dataalta			   date			   CONSTRAINT NN_dataaltaPartit NOT NULL,
  usualta			   varchar2(20)	CONSTRAINT NN_usualtaPartit NOT NULL,
  datamod			   date,
  databaixa			   date,
  usumod			      varchar2(20),
  usubaixa			   varchar2(20),  
  CONSTRAINT PK_Partit  PRIMARY KEY (id),
  CONSTRAINT CH_upperDocPartit CHECK (document=UPPER(TRIM(document)))
);
COMMENT ON TABLE Partit IS 'Taula de partits polítics';
COMMENT ON COLUMN Partit.id IS 'Codi indentificatiu intern del partit';
COMMENT ON COLUMN Partit.document IS 'Document identificatiu del partit';
COMMENT ON COLUMN Partit.nom IS 'Nom del partit';
COMMENT ON COLUMN Partit.dataalta IS 'Data d''alta del registre';
COMMENT ON COLUMN Partit.usualta IS 'Usuari alta del registre';
COMMENT ON COLUMN Partit.datamod IS 'Data darrera modificació del registre';
COMMENT ON COLUMN Partit.usumod Is 'Usuari darrera modificació del registre';
COMMENT ON COLUMN Partit.databaixa IS 'Data baixa del registre';
COMMENT ON COLUMN Partit.usubaixa IS 'Usuari baixa del registre';

CREATE TABLE Parlament (
  id               	number(10) 		CONSTRAINT NN_idParlament NOT NULL, 
  document         	varchar2(20) 	CONSTRAINT NN_documentParlament NOT NULL CONSTRAINT UN_documentParlament UNIQUE, 
  nom              	varchar2(50) 	CONSTRAINT NN_nomParlament NOT NULL, 
  pais             	varchar2(2) 	CONSTRAINT NN_paisParlament NOT NULL, 
  regio              VARCHAR2(2),
  numParlamentaris 	number(10) 		DEFAULT 0 CONSTRAINT NN_numParlamentarisParlament NOT NULL, 
  direccio         	varchar2(100) 	CONSTRAINT NN_direccioParlament NOT NULL, 
  telefon          	varchar2(15) 	CONSTRAINT NN_telefonParlament NOT NULL, 
  web              	varchar2(100), 
  dataalta			   date			CONSTRAINT NN_dataaltaParlament NOT NULL,
  usualta			   varchar2(20)	CONSTRAINT NN_usualtaParlament NOT NULL,
  datamod			   date,
  usumod			      varchar2(20),
  databaixa		   	date,
  usubaixa		   	varchar2(20),  
  CONSTRAINT PK_Parlament PRIMARY KEY (id),
  CONSTRAINT CH_upperDocParlament CHECK (document=UPPER(TRIM(document))),
  CONSTRAINT UN_paisregioParlament UNIQUE (pais, regio)
);
COMMENT ON TABLE Parlament IS 'Taula amb la definició dels parlaments';
COMMENT ON COLUMN Parlament.id IS 'Codi identificatiu intern del parlament';
COMMENT ON COLUMN Parlament.document IS 'Document identificatiu del parlament';
COMMENT ON COLUMN Parlament.nom IS 'Nom del parlament';
COMMENT ON COLUMN Parlament.pais IS 'Pais al qual pertany el parlament';
COMMENT ON COLUMN Parlament.regio IS 'Regio del pais a la que pertany el parlament';
COMMENT ON COLUMN Parlament.numParlamentaris IS 'Nombre de parlamentaris actius del parlament';
COMMENT ON COLUMN Parlament.direccio IS 'Direcció de la seu del parlament';
COMMENT ON COLUMN Parlament.telefon IS 'Numero de telefon del parlament';
COMMENT ON COLUMN Parlament.web Is 'URL de la web del parlament';
COMMENT ON COLUMN Parlament.dataalta IS 'Data d''alta del registre';
COMMENT ON COLUMN Parlament.usualta IS 'Usuari alta del registre';
COMMENT ON COLUMN Parlament.datamod IS 'Data darrera modificació del registre';
COMMENT ON COLUMN Parlament.usumod Is 'Usuari darrera modificació del registre';
COMMENT ON COLUMN Parlament.databaixa IS 'Data baixa del registre';
COMMENT ON COLUMN Parlament.usubaixa IS 'Usuari baixa del registre';


CREATE TABLE Parlamentari (
  id				      number(10)		CONSTRAINT NN_idParlamentari NOT NULL, 
  document         	varchar2(20) 	CONSTRAINT NN_documentParlamentari NOT NULL CONSTRAINT UN_documentParlamentari UNIQUE, 
  parlament        	number(10) 		CONSTRAINT NN_parlamentParlamentari NOT NULL, 
  partit           	number(10) 		CONSTRAINT NN_partitParlamentari NOT NULL, 
  nom              	varchar2(50) 	CONSTRAINT NN_nomParlamentari NOT NULL, 
  cognoms          	varchar2(100) 	CONSTRAINT NN_cognomsParlamentari NOT NULL, 
  numIdentificacio 	varchar2(20)  	CONSTRAINT NN_numIdentParlamentari NOT NULL, 
  numTargeta       	varchar2(20),
  dataalta			   date			CONSTRAINT NN_dataaltaParlamentari NOT NULL,
  usualta			   varchar2(20)	CONSTRAINT NN_usualtaParlamentari NOT NULL,
  usumod			      varchar2(20),  
  datamod			   date,
  databaixa			   date,
  usubaixa			   varchar2(20),   
  CONSTRAINT PK_Parlamentari PRIMARY KEY (id),
  CONSTRAINT CH_upperdocParlamentari CHECK (document=UPPER(TRIM(document))),
  CONSTRAINT CH_upperIdentParlamentari CHECK (numIdentificacio=UPPER(TRIM(numIdentificacio))),
  CONSTRAINT UN_parlamentIdentParlamentari UNIQUE (parlament, numIdentificacio)
);
COMMENT ON TABLE Parlamentari IS 'Taula de parlamentaris';
COMMENT ON COLUMN Parlamentari.id IS 'Codi identificatiu intern del parlamentari';
COMMENT ON COLUMN Parlamentari.document IS 'Document identificatiu del parlamentari';
COMMENT ON COLUMN Parlamentari.parlament IS 'Codi identificatiu del parlament al que pertany';
COMMENT ON COLUMN Parlamentari.partit IS 'Codi identificatiu del partit al que pertany';
COMMENT ON COLUMN Parlamentari.nom IS 'Nom del parlamentari';
COMMENT ON COLUMN Parlamentari.cognoms IS 'Llinatges del parlamentari';
COMMENT ON COLUMN Parlamentari.numIdentificacio IS 'Numero identificatiu del parlamentari';
COMMENT ON COLUMN Parlamentari.numTargeta IS 'Numero de targeta associada al parlamentari';
COMMENT ON COLUMN Parlamentari.dataalta IS 'Data d''alta del registre';
COMMENT ON COLUMN Parlamentari.usualta IS 'Usuari alta del registre';
COMMENT ON COLUMN Parlamentari.datamod IS 'Data darrera modificació del registre';
COMMENT ON COLUMN Parlamentari.usumod Is 'Usuari darrera modificació del registre';
COMMENT ON COLUMN Parlamentari.databaixa IS 'Data baixa del registre';
COMMENT ON COLUMN Parlamentari.usubaixa IS 'Usuari baixa del registre';


CREATE TABLE Pais (
  codi 				varchar2(2) 	CONSTRAINT NN_codiParis NOT NULL CONSTRAINT CH_uppercodiPais CHECK (codi=TRIM(UPPER(codi))), 
  nom			  	   varchar2(50) 	CONSTRAINT NN_nomPais NOT NULL, 
  CONSTRAINT PK_Pais PRIMARY KEY (codi)
);
COMMENT ON TABLE Pais IS 'Taula amb la codificació i nom dels paisos';
COMMENT ON COLUMN Pais.codi IS 'Codi del pais';
COMMENT ON COLUMN Pais.nom IS 'Literal del pais';

CREATE TABLE Regio (
   codi           VARCHAR2(2)    CONSTRAINT NN_codiRegio NOT NULL CONSTRAINT CH_uppercodiRegio CHECK (codi=TRIM(UPPER(codi))),
   pais           VARCHAR2(2)    CONSTRAINT NN_paisRegio NOT NULL,
   nom            VARCHAR2(50)   CONSTRAINT NN_nomRegio  NOT NULL,   
   CONSTRAINT PK_REGIO PRIMARY KEY (codi, pais)
);
COMMENT ON TABLE Regio IS 'Taula amb les regions de cada pais';
COMMENT ON COLUMN Regio.codi IS 'Codi de la regio del pais';
COMMENT ON COLUMN Regio.pais IS 'Codi del pais al que pertany';
COMMENT ON COLUMN Regio.nom IS 'Literal de la regio';
   

CREATE TABLE TipusDespesa (
  origen     		number(2) 		CONSTRAINT NN_origenTipusDespesa NOT NULL CONSTRAINT CH_Origen_Despesa CHECK (origen in (1,2)), 
  codi       		number(10) 		CONSTRAINT NN_codiTipusDespesa NOT NULL, 
  descripcio 		varchar2(100) 	CONSTRAINT NN_descripcioTipusDespesa NOT NULL, 
  CONSTRAINT PK_TipusDespesa PRIMARY KEY (origen, codi)
);
COMMENT ON TABLE TipusDespesa IS 'Taula amb els tipus de despesa i l''origen de la despesa';
COMMENT ON COLUMN TipusDespesa.origen IS 'Tipus de despesa. 1-Parlament; 2-Parlamentari';
COMMENT ON COLUMN TipusDespesa.codi IS 'Codi de la despesa';
COMMENT ON COLUMN TipusDespesa.descripcio IS 'Descripció de la despesa';
  
CREATE TABLE Despesa (
  id            	number(10) 		CONSTRAINT NN_idDespesa NOT NULL, 
  origendespesa 	number(2) 		CONSTRAINT NN_origenDespesa NOT NULL CONSTRAINT CH_TIPO_DESPESA CHECK (origendespesa in (1,2)), 
  codidespesa   	number(10) 		CONSTRAINT NN_codiDespesa NOT NULL, 
  parlament     	number(10) 		CONSTRAINT NN_parlamentDespesa NOT NULL, 
  formapagament 	number(10) 		CONSTRAINT NN_formapagamentDespesa NOT NULL, 
  estatdespesa  	number(10) 		CONSTRAINT NN_estatDespesa NOT NULL, 
  data         	date 			   CONSTRAINT NN_dataDespesa NOT NULL, 
  anyo				number(4)		CONSTRAINT NN_anyoDespesa NOT NULL,
  ibrut         	number(15, 2) 	CONSTRAINT NN_ibrutDespesa NOT NULL  CONSTRAINT CH_IMPORTDESPESA CHECK (ibrut > 0), 
  iva           	number(5, 2) 	CONSTRAINT NN_ivaDespesa NOT NULL CONSTRAINT CH_IVADESPESA CHECK (iva >= 0), 
  inet          	number(15, 2) 	CONSTRAINT NN_inetDespesa NOT NULL, 
  descripcio    	varchar2(250) 	CONSTRAINT NN_descripcioDespesa NOT NULL, 
  justificacio  	varchar2(2500) CONSTRAINT NN_justificacioDespesa NOT NULL, 
  parlamentari  	number(10), 
  partit        	number(10), 
  empresa			varchar2(200),
  urldocument   	varchar2(250), 
  numtargeta      varchar2(20),
  iban            varchar2(34),
  dataalta			date			   CONSTRAINT NN_dataaltaDespesa NOT NULL,
  usualta			varchar2(20)	CONSTRAINT NN_usualtaDespesa NOT NULL,
  datamod			date,
  usumod			   varchar2(20),
  databaixa			date,
  usubaixa			varchar2(20),
  CONSTRAINT PK_Despesa PRIMARY KEY (id)  
);
COMMENT ON TABLE Despesa IS 'Taula amb totes les Despeses';
COMMENT ON COLUMN Despesa.id IS 'Codi identificatiu intern de la despesa';
COMMENT ON COLUMN Despesa.origendespesa IS 'Origen de la despesa. 1-Parlament; 2-Parlamentari';
COMMENT ON COLUMN Despesa.codidespesa IS 'Codi del tipus de despesa';
COMMENT ON COLUMN Despesa.parlament IS 'Codi identificatiu intern del parlament';
COMMENT ON COLUMN Despesa.formapagament IS 'Codi forma de pagament';
COMMENT ON COLUMN Despesa.estatdespesa IS 'Codi estat de la despesa';
COMMENT ON COLUMN Despesa.data IS 'Data de la despesa';
COMMENT ON COLUMN Despesa.anyo IS 'Any de la despesa';
COMMENT ON COLUMN Despesa.ibrut IS 'Import brut de la despesa';
COMMENT ON COLUMN Despesa.iva IS 'Percentatge d''IVA';
COMMENT ON COLUMN Despesa.inet IS 'Import net de la despesa';
COMMENT ON COLUMN Despesa.descripcio IS '';
COMMENT ON COLUMN Despesa.justificacio IS '';
COMMENT ON COLUMN Despesa.parlamentari IS 'Codi identificatiu intern del parlamentari';
COMMENT ON COLUMN Despesa.partit IS 'Codi identificatiu intern del partit al que pertany el parlamentari';
COMMENT ON COLUMN Despesa.empresa IS 'Dades de l''empresa de la despesa';
COMMENT ON COLUMN Despesa.urldocument IS 'URL dels documents de la despesa';
COMMENT ON COLUMN Despesa.numtargeta IS 'Numero de targeta amb la que es paga la despesa';
COMMENT ON COLUMN Despesa.iban IS 'Numero de compte amb la que es paga la despesa';
COMMENT ON COLUMN Despesa.dataalta IS 'Data d''alta del registre';
COMMENT ON COLUMN Despesa.usualta IS 'Usuari alta del registre';
COMMENT ON COLUMN Despesa.datamod IS 'Data darrera modificació del registre';
COMMENT ON COLUMN Despesa.usumod Is 'Usuari darrera modificació del registre';
COMMENT ON COLUMN Despesa.databaixa IS 'Data baixa del registre';
COMMENT ON COLUMN Despesa.usubaixa IS 'Usuari baixa del registre';


CREATE TABLE FormaPagament (
  id         		number(10) 		CONSTRAINT NN_idFormaPagament NOT NULL, 
  descripcio 		varchar2(100) 	CONSTRAINT NN_descripcioFormaPagament NOT NULL, 
  CONSTRAINT PK_FormaPagament PRIMARY KEY (id)
);
COMMENT ON TABLE FormaPagament IS 'Taula amb les distintes formes de pagament';
COMMENT ON COLUMN FormaPagament.id IS 'Codi forma de pagament';
COMMENT ON COLUMN FormaPagament.descripcio IS 'Descripció forma de pagament';

CREATE TABLE EstatDespesa (
  id         		number(10) 		CONSTRAINT NN_idEstatDespesa NOT NULL, 
  descripcio 		varchar2(100) 	CONSTRAINT NN_descripcioEstatDespesa NOT NULL, 
  CONSTRAINT PK_EstatDespesa PRIMARY KEY (id)
);
COMMENT ON TABLE EstatDespesa IS 'Taula amb els distints estat que pot tenir una despesa';
COMMENT ON COLUMN EstatDespesa.id IS 'Codi estat de la despesa';
COMMENT ON COLUMN EstatDespesa.descripcio IS 'Descripció estat de la despesa';
    
CREATE TABLE Logs (
  id      			number(10) 		CONSTRAINT NN_idLogs NOT NULL, 
  data   			timestamp 		CONSTRAINT NN_dataLogs NOT NULL, 
  nomproc 			varchar2(50) 	CONSTRAINT NN_nomprocLogs NOT NULL, 
  RSP     			varchar2(500)	CONSTRAINT NN_rspLogs NOT NULL, 
  parin   			varchar2(500), 
  CONSTRAINT PK_Logs PRIMARY KEY (id)
);
COMMENT ON TABLE Logs IS 'Taula on es registres totes les crides i parametres que es fan';
COMMENT ON COLUMN Logs.id IS 'Identificador intern';
COMMENT ON COLUMN Logs.data IS 'Data d''execució';
COMMENT ON COLUMN Logs.nomproc IS 'Nom del procés';
COMMENT ON COLUMN Logs.rsp IS 'Resposta del procés';
COMMENT ON COLUMN Logs.parin IS 'Paràmetres d''entrada al procés';

	
ALTER TABLE Parlament ADD CONSTRAINT FK_PARLAMENT_PAIS FOREIGN KEY (pais) REFERENCES Pais (codi);
ALTER TABLE Parlament ADD CONSTRAINT FK_PARLAMENT_REGIO FOREIGN KEY (pais, regio) REFERENCES Regio (pais, codi);
ALTER TABLE Parlamentari ADD CONSTRAINT FK_PARLAMENTARI_PARLAMENT FOREIGN KEY (parlament) REFERENCES Parlament (id);
ALTER TABLE Parlamentari ADD CONSTRAINT FK_PARLAMENTARI_PARTIT FOREIGN KEY (partit) REFERENCES Partit (id);
ALTER TABLE Despesa ADD CONSTRAINT FK_DESPESA_TIPUSDESPESA FOREIGN KEY (origendespesa, codidespesa) REFERENCES TipusDespesa (origen, codi);
ALTER TABLE Despesa ADD CONSTRAINT FK_DESPESA_PARLAMENT FOREIGN KEY (parlament) REFERENCES Parlament (id);
ALTER TABLE Despesa ADD CONSTRAINT FK_DESPESA_PARLAMENTARI FOREIGN KEY (parlamentari) REFERENCES Parlamentari (id);
ALTER TABLE Despesa ADD CONSTRAINT FK_DESPESA_PARTIT FOREIGN KEY (partit) REFERENCES Partit (id);
ALTER TABLE Despesa ADD CONSTRAINT FK_DESPESA_FORMAPAGAMENT FOREIGN KEY (formapagament) REFERENCES FormaPagament (id);
ALTER TABLE Despesa ADD CONSTRAINT FK_DESPESA_ESTATDESPESA FOREIGN KEY (estatdespesa) REFERENCES EstatDespesa (id);
ALTER TABLE Regio ADD CONSTRAINT FK_REGIO_PAIS FOREIGN KEY (pais) REFERENCES Pais (codi);

----- TAULES MODUL ESTADISTIC
/*
1. Donat un parlament: la suma de totes les despeses dels
darrers 4 anys (incloent les despeses generals dels
parlaments i les despeses associades als parlamentaris).
*/
CREATE TABLE EstParlamentAnys (
   parlament            NUMBER(10)        CONSTRAINT NN_parlamentEstParlamentAnys NOT NULL,
   nom                  VARCHAR2(50)      CONSTRAINT NN_nomEstParlamentAnys NOT NULL,
   total                NUMBER(20,2)      CONSTRAINT NN_totalEstParlamentAnys NOT NULL,
   CONSTRAINT PK_EstParlamentAnys PRIMARY KEY (parlament),
   CONSTRAINT FK_EstParlamentAnys_Parlament FOREIGN KEY (parlament) REFERENCES Parlament(id)
);
COMMENT ON TABLE EstParlamentAnys IS 'Suma de despeses dels darrers 4 anys per parlament';
COMMENT ON COLUMN EstParlamentAnys.parlament IS 'Codi indentficatiu del parlament';
COMMENT ON COLUMN EstParlamentAnys.nom IS 'Nom del parlament';
COMMENT ON COLUMN EstParlamentAnys.total IS 'Despesa del darrers 4 anys';

/*
2. Donat un parlament i any: la diferencia en euros entre el
parlamentari que més despeses associades té i el que
menys.
*/
CREATE TABLE EstParlamentParlamentari (
   anyo                    NUMBER(4)      CONSTRAINT NN_anyoEstParlamentParla    NOT NULL,
   parlament               NUMBER(10)     CONSTRAINT NN_parlament_EstParlamentParla NOT NULL,
   parlamentariMenys       NUMBER(10)     CONSTRAINT NN_parlaMenysEstParlamentParla NOT NULL,
   nomMenys                VARCHAR2 (151) CONSTRAINT NN_nomMenysEstParlamentParla NOT NULL,
   totalMenys              NUMBER(20,2)   CONSTRAINT NN_totalMenysEstParlamentParla NOT NULL,
   parlamentariMes         NUMBER(10)     CONSTRAINT NN_parlaMesEstParlamentParla NOT NULL,
   nomMes                  VARCHAR2(151)  CONSTRAINT NN_nomMesEstParlamentParla NOT NULL,
   totalMes                NUMBER(20,2)   CONSTRAINT NN_totalMesEstParlamentParla NOT NULL,
   diferencia              NUMBER(20,2)   CONSTRAINT NN_diferenciaEstParlamentParla NOT NULL,   
   CONSTRAINT PK_EstParlamentParlamentari PRIMARY KEY (anyo, parlament),
   CONSTRAINT PK_EstParlamentParlament    FOREIGN KEY (parlament) REFERENCES parlament(id),
   CONSTRAINT FK_EstParlamentParla_Parla_1 FOREIGN KEY (parlamentariMenys) REFERENCES parlamentari(id),
   CONSTRAINT FK_EstParlamentParla_Parla_2 FOREIGN KEY (parlamentariMes) REFERENCES parlamentari(id)
);
COMMENT ON TABLE EstParlamentParlamentari IS 'Taula amb el parlamentari que menys i mes gasta per parlament i any';
COMMENT ON COLUMN EstParlamentParlamentari.anyo IS 'Any';
COMMENT ON COLUMN EstParlamentParlamentari.parlament IS 'Codi identificatiu del parlament';
COMMENT ON COLUMN EstParlamentParlamentari.parlamentariMenys IS 'Codi del parlamentari amb menys despesa';
COMMENT ON COLUMN EstParlamentParlamentari.nomMenys IS 'Nom del parlamentari amb menys despesa';
COMMENT ON COLUMN EstParlamentParlamentari.totalMenys IS 'Total despesa del parlamentari amb menys despesa';
COMMENT ON COLUMN EstParlamentParlamentari.parlamentariMes IS 'Codi del parlamentari amb més despesa';
COMMENT ON COLUMN EstParlamentParlamentari.nomMes IS 'Nom del parlamentari amb més despesa';
COMMENT ON COLUMN EstParlamentParlamentari.totalMes IS 'Total despesa del parlamentari amb més despesa';
COMMENT ON COLUMN EstParlamentParlamentari.diferencia IS 'Diferencia entre parlamentaris';

/*
3. Donat un any concret: el parlament que ha tingut un total de
despeses més alt (incloent les despeses generals dels
parlaments i les despeses associades als parlamentaris).
*/
CREATE TABLE EstParlamentMesAlta (
   anyo                    NUMBER(4)      CONSTRAINT NN_anyoEstParlamentMesAlta NOT NULL,
   parlament               NUMBER(10)     CONSTRAINT NN_parlaEstParlamentMesAlta NOT NULL,
   nom                     VARCHAR2(50)   CONSTRAINT NN_nomEstParlamentMesAlta NOT NULL,
   total                   NUMBER(20,2)   CONSTRAINT NN_totalEstParlamentMesAlta NOT NULL,   
   CONSTRAINT PK_EstParlamentMesAlta PRIMARY KEY (anyo),
   CONSTRAINT FK_EstParlamentMAlta_Parlament FOREIGN KEY (parlament) REFERENCES Parlament(id)
);
COMMENT ON TABLE EstParlamentMesAlta IS 'Parlament que ha tingut més despesa per any';
COMMENT ON COLUMN EstParlamentMesAlta.anyo IS 'Any';
COMMENT ON COLUMN EstParlamentMesAlta.parlament IS 'Codi identificatiu del parlament';
COMMENT ON COLUMN EstParlamentMesAlta.nom IS 'Nom del parlament';
COMMENT ON COLUMN EstParlamentMesAlta.total IS 'Total de despesa';

/*
4. Donat un parlamentari: la despesa total que ha tingut els
darrers 4 anys
*/
CREATE TABLE EstParlamentariAnys (
   parlamentari            NUMBER(10)     CONSTRAINT NN_parlamEstParlamentariAnys NOT NULL,
   nom                     VARCHAR2(151)  CONSTRAINT NN_nomEstParlamentariAnys NOT NULL,
   total                   NUMBER(20,2)   CONSTRAINT NN_totalEstParlamentariAnys NOT NULL,   
   CONSTRAINT PK_EstParlamentariAnys PRIMARY KEY (parlamentari),
   CONSTRAINT FK_EstParlaAnys_Parlamentari FOREIGN KEY (parlamentari) REFERENCES Parlamentari (id)
);
COMMENT ON TABLE EstParlamentariAnys IS 'Suma de despeses dels darrers 4 anys per parlamentari';
COMMENT ON COLUMN EstParlamentariAnys.parlamentari IS 'Codi identificatiu del parlamentari';
COMMENT ON COLUMN EstParlamentariAnys.nom IS 'Nom del parlamentari';
COMMENT ON COLUMN EstParlamentariAnys.total IS 'Despesa del darrers 4 anys';

/*
5. Donat un any concret: la mitjana de despesa d’un
parlamentari durant aquell any (tenint en compte tots els
parlamentaris de tots els parlaments).
*/

CREATE TABLE EstMitjanaParlamentari (
   anyo                    NUMBER(4)      CONSTRAINT NN_anyoEstMitjaParlamentari NOT NULL,
   mitjana                 NUMBER(20,2)   CONSTRAINT NN_mitjanaEstMitjaParlamentari NOT NULL,   
   CONSTRAINT PK_EstMitjaParlamentari PRIMARY KEY (anyo)
);
COMMENT ON TABLE EstMitjanaParlamentari IS 'Mitjana de despesa d''un parlamentari per any';
COMMENT ON COLUMN EstMitjanaParlamentari.anyo IS 'Any';
COMMENT ON COLUMN EstMitjanaParlamentari.mitjana IS 'Mitjana despesa parlamentari';

/*
6. Donat un any concret: el parlamentari que ha tingut més
despesa associada i el que menys (tenint en compte tots els
parlaments).
*/
CREATE TABLE EstParlamentarisOposats (
   anyo                    NUMBER(4)      CONSTRAINT NN_anyoEstOposats NOT NULL,
   parlamentariMenys       NUMBER(10)     CONSTRAINT NN_parlamentariMenysEstOposats NOT NULL,
   nomMenys                VARCHAR2(151)  CONSTRAINT NN_nomMenysEstOposats NOT NULL,
   despesaMenys            NUMBER(20,2)   CONSTRAINT NN_despesaMenysEstOposats NOT NULL,
   parlamentariMes         NUMBER(10)     CONSTRAINT NN_parlamentariMesEstOposats NOT NULL,
   nomMes                  VARCHAR2(151)  CONSTRAINT NN_nomMesEstOposats NOT NULL,
   despesaMes              NUMBER(20,2)   CONSTRAINT NN_despesaMesEstOposats NOT NULL,   
   CONSTRAINT PK_EstParlamentarisOposats PRIMARY KEY (anyo),
   CONSTRAINT FK_EstOposats_Parlamentari_1 FOREIGN KEY (parlamentariMenys) REFERENCES Parlamentari(id),
   CONSTRAINT FK_EstOposats_Parlamentari_2 FOREIGN KEY (parlamentariMes) REFERENCES Parlamentari(id)
);
COMMENT ON TABLE EstParlamentarisOposats IS 'De tots els parlamentaris el que més i menys despesa associada te';
COMMENT ON COLUMN EstParlamentarisOposats.anyo IS 'Any';
COMMENT ON COLUMN EstParlamentarisOposats.parlamentariMenys IS 'Codi del parlamentari amb menys despesa';
COMMENT ON COLUMN EstParlamentarisOposats.nomMenys IS 'Nom del parlamentari amb menys despesa';
COMMENT ON COLUMN EstParlamentarisOposats.despesaMenys IS 'Total de despesa del parlamentari amb menys despesa';
COMMENT ON COLUMN EstParlamentarisOposats.parlamentariMes IS 'Codi del parlamentari amb més despesa';
COMMENT ON COLUMN EstParlamentarisOposats.nomMes IS 'Nom del parlamentari amb més despesa';
COMMENT ON COLUMN EstParlamentarisOposats.despesaMes IS 'Total de despesa del parlamentari amb més despesa';

/*
7. Donat un any concret: el nom del parlament amb una
mitjana de despesa associada als seus parlamentaris més
alta, i el valor d’aquesta mitjana de despesa.
*/
CREATE TABLE EstMitjaParlament (
   anyo                    NUMBER(4)      CONSTRAINT NN_anyoEstMitjaParlament NOT NULL,
   parlament               NUMBER(10)     CONSTRAINT NN_parlamentEstMitjaParlament NOT NULL,
   nom                     VARCHAR2(50)   CONSTRAINT NN_nomEstMitjaParlament NOT NULL,
   mitjana                 NUMBER(20,2)   CONSTRAINT NN_mitjanaEstMitjaParlament NOT NULL,   
   CONSTRAINT PK_EstMitjaParlament PRIMARY KEY (anyo),
   CONSTRAINT FK_EstMitjaParlament_Parlament FOREIGN KEY (parlament) REFERENCES Parlament (id)
);
COMMENT ON TABLE EstMitjaParlament IS 'Parlament amb la despesa de parlamentari més alta';
COMMENT ON COLUMN EstMitjaParlament.anyo IS 'Any';
COMMENT ON COLUMN EstMitjaParlament.parlament IS 'Codi identificatiu del parlament';
COMMENT ON COLUMN EstMitjaParlament.nom IS 'Nom del parlament';
COMMENT ON COLUMN EstMitjaParlament.mitjana IS 'Mitjana dels parlamentaris';

/*
8. Donat un any concret: la suma de totes les despeses de tots
els parlaments (incloent les despeses generals dels
parlaments i les despeses associades als parlamentaris).
*/
CREATE TABLE EstTotal (
   anyo                    NUMBER(4)      CONSTRAINT NN_anyoEstTotal NOT NULL,
   total                   NUMBER(20,2)   CONSTRAINT NN_totalEstTotal NOT NULL,   
   CONSTRAINT PK_EstTotal PRIMARY KEY (anyo)
);
COMMENT ON TABLE EstTotal IS 'Total de despesa per any';
COMMENT ON COLUMN EstTotal.anyo IS 'Any';
COMMENT ON COLUMN EstTotal.total IS 'Total de despesa per any';
