/**
*<p>Despesa segmentada per categoria d'un parlament en un any concret. 
*Aquesta informa del codi de la despesa, la descripció de la despesa i 
*la suma de la despesa realitzat pel parlament durant l'any.
*@author Toni Torres
*
*@param  p_any       Any
*@param  p_parlament Codi identificatiu intern del parlament
*@return tab_desp_segmen_categoria
*/
CREATE OR REPLACE FUNCTION desp_segmen_categoria (
   p_any             despesa.anyo%TYPE,
   p_parlament       despesa.parlament%TYPE
)
   RETURN tab_desp_segmen_categoria
IS
   v_nomproc	      logs.nomproc%TYPE := 'desp_segmen_categoria';
   v_parin		      logs.parin%TYPE;
   RSP               logs.rsp%TYPE := 'OK';
   
   v_contador        NUMBER := 0;
   v_consulta        tab_desp_segmen_categoria := tab_desp_segmen_categoria();
   
   CURSOR consulta (p_any NUMBER, p_parlamnet NUMBER) IS
      SELECT d.codidespesa, t.descripcio, SUM(d.inet) TOTAL
        FROM despesavigent d INNER JOIN tipusdespesa t ON (d.origendespesa = t.origen AND d.codidespesa=t.codi)           
       WHERE d.anyo = p_any
         AND d.parlament = p_parlament         
       GROUP BY d.codidespesa, t.descripcio
       ORDER BY d.codidespesa, t.descripcio;
BEGIN
   v_parin := CONCAT('p_any=', p_any);
   v_parin := v_parin || CONCAT('; p_parlament=', p_parlament);
   
   FOR reg IN consulta (p_any, p_parlament)
   LOOP
      v_contador := v_contador + 1;
      v_consulta.EXTEND;
      v_consulta(v_contador) := obj_desp_segmen_categoria(reg.codidespesa, 
                                 reg.descripcio, reg.total);
   END LOOP;
   p_log (v_nomproc, v_parin, RSP);
   RETURN v_consulta;
EXCEPTION
   WHEN OTHERS
   THEN
      RSP :=  CONCAT(PK_ERRORS.ERR_NOTRACTAT, (TO_CHAR(SQLCODE) || ' '|| SUBSTR(SQLERRM,1,400)));
      p_log (v_nomproc, v_parin, RSP);
      RETURN NULL;
END desp_segmen_categoria;
/
