/**
*<p>Despesa total de tos els parlament en un any. Aquesta informa les dades 
*del parlament, la despesa mitja dels seus parlamentaris, la despesa total 
*dels seus parlamentari, la despesa total originada exclusivament pel 
*parlament i la despesa total del parlament.
*@author Toni Torres
*
*@param p_any     Any
*@return tab_desp_total_parlaments
*/

CREATE OR REPLACE FUNCTION desp_total_parlaments (
   p_any             despesa.anyo%TYPE
)
   RETURN tab_desp_total_parlaments
IS
   v_nomproc	      logs.nomproc%TYPE := 'desp_total_parlaments';
   v_parin		      logs.parin%TYPE;
   RSP               logs.rsp%TYPE := 'OK';

   v_consulta     tab_desp_total_parlaments := tab_desp_total_parlaments();
   v_contador     NUMBER := 0;
   
   CURSOR consulta (p_any NUMBER) IS
      SELECT p.nom, p.numparlamentaris, NVL(calcparlamentaris.mitja,0) MITJAPARLAMENTARIS, 
             NVL(calcparlamentaris.total,0) TOTALPARLAMENTARIS, 
             NVL(calcparlament.total,0) TOTALPARLAMENT, SUM(d.inet) TOTAL
        FROM despesavigent d INNER JOIN parlament p ON (d.parlament=p.id)
             LEFT JOIN (SELECT parlament,anyo, avg(inet) mitja, sum(inet) total
                           FROM despesavigent
                          WHERE origendespesa = 2
                          GROUP BY parlament,anyo) calcparlamentaris 
             ON (d.parlament=calcparlamentaris.parlament AND d.anyo = calcparlamentaris.anyo)
             LEFT JOIN (SELECT parlament,anyo, sum(inet) total
                           FROM despesavigent
                          WHERE origendespesa = 1
                          GROUP BY parlament,anyo) calcparlament 
             ON (d.parlament = calcparlament.parlament AND d.anyo = calcparlament.anyo)
       WHERE d.anyo = p_any
       GROUP BY p.id, p.nom, p.numparlamentaris, calcparlamentaris.mitja, calcparlamentaris.total, calcparlament.total;
BEGIN
   v_parin := CONCAT('p_any=', p_any);   
   
   FOR reg IN consulta(p_any)
   LOOP
      v_contador := v_contador + 1;
      v_consulta.extend;
      v_consulta(v_contador) := obj_desp_total_parlaments(reg.nom, reg.numparlamentaris,
                                reg.MITJAPARLAMENTARIS, reg.TOTALPARLAMENTARIS,
                                reg.TOTALPARLAMENT, reg.TOTAL);
   END LOOP;
   p_log (v_nomproc, v_parin, RSP);
   RETURN v_consulta;
EXCEPTION
   WHEN OTHERS
   THEN
      RSP :=  CONCAT(PK_ERRORS.ERR_NOTRACTAT, (TO_CHAR(SQLCODE) || ' '|| SUBSTR(SQLERRM,1,400)));
      p_log (v_nomproc, v_parin, RSP);
      RETURN NULL;
END desp_total_parlaments;
/
