/**
*<p>Llistat de totes les despeses d'un parlamentari donat un parlament, 
*parlamentari i any en concret.</p>
*<p>Aquesta informa de l'identificador de la despesa, data de la despesa, 
*tipus de despesa, empresa, import brut, iva, import net, estat de la despesa, 
*forma de pagament, IBAN i número de targeta.</p>
*@author Toni Torres
*
*@param  p_parlament       Codi identificatiu intern del parlament
*@param  p_parlamentari    Codi identificatiu intern del parlamentari
*@param  p_any             Any
*@return tab_despeses_parlamentari_any
*/
CREATE OR REPLACE FUNCTION despeses_parlamentari_any (
   p_parlament         despesa.parlament%TYPE,
   p_parlamentari      despesa.parlamentari%TYPE,
   p_any              despesa.anyo%TYPE
) 
   RETURN tab_despeses_parlamentari_any
IS 
   v_nomproc	      logs.nomproc%TYPE := 'despeses_parlamentari_any';
   v_parin		      logs.parin%TYPE;
   RSP               logs.rsp%TYPE := 'OK';
   
   v_contador  NUMBER := 0;
   v_consulta  tab_despeses_parlamentari_any := tab_despeses_parlamentari_any();
   
   CURSOR consulta (p_parlament NUMBER, p_parlamentari NUMBER, p_any NUMBER)  IS 
      SELECT d.id, d.data, d.codidespesa,t.descripcio despesa, d.empresa, d.ibrut, d.iva,
             d.inet, e.descripcio estat, f.descripcio pagament, d.iban, d.numtargeta
        FROM despesavigent d INNER JOIN formapagament f ON (d.formapagament = f.id)
             INNER JOIN estatdespesa e ON (d.estatdespesa = e.id)
             INNER JOIN tipusdespesa t ON (d.origendespesa = t.origen AND d.codidespesa=t.codi)
       WHERE d.parlament = p_parlament
         AND d.parlamentari = p_parlamentari
         AND d.anyo = p_any
       ORDER BY d.inet DESC;   
BEGIN
   v_parin := CONCAT('p_parlament=', p_parlament);
   v_parin := v_parin || CONCAT('; p_parlamentari=', p_parlamentari);
   v_parin := v_parin || CONCAT('; p_any=', p_any);
   
   FOR reg IN consulta (p_parlament, p_parlamentari, p_any)
   LOOP
      v_contador := v_contador + 1;
      v_consulta.EXTEND;
      v_consulta(v_contador) := obj_despeses_parlamentari_any (reg.id, reg.data, reg.codidespesa,
                                reg.despesa, reg.empresa, reg.ibrut, reg.iva, reg.inet,
                                reg.estat, reg.pagament, reg.iban, reg.numtargeta);
   END LOOP;
   p_log (v_nomproc, v_parin, RSP);
   RETURN v_consulta;
EXCEPTION
   WHEN OTHERS
   THEN
      RSP := CONCAT(PK_ERRORS.ERR_NOTRACTAT, (TO_CHAR(SQLCODE) || ' '|| SUBSTR(SQLERRM,1,400)));
      p_log (v_nomproc, v_parin, RSP);
      RETURN NULL;
END despeses_parlamentari_any;
/
