/**
*<p>Llistat de tots els parlaments amb el seu estat comptable en un any. Aquesta informa 
*el nom del parlament, el nombre de parlamentaris, total despeses pendent d'aprovació, 
*total despeses aprovades, total despeses pendent d'abonament i total despeses 
*abonades.</p>
*@author Toni Torres
*
*@param  p_any       Any
*@return tab_estat_comptable
*/
CREATE OR REPLACE FUNCTION estat_comptable (
   p_any             despesa.anyo%TYPE
)
   RETURN tab_estat_comptable
IS   
   v_nomproc	      logs.nomproc%TYPE := 'estat_comptable';
   v_parin		      logs.parin%TYPE;
   RSP               logs.rsp%TYPE := 'OK';
   
   v_contador     NUMBER := 0;
   v_consulta     tab_estat_comptable := tab_estat_comptable ();
   
   CURSOR consulta (p_any NUMBER) IS
      SELECT p.nom, p.numparlamentaris, SUM(decode (d.estatdespesa,1,inet, 0)) pdteaprovada,
             SUM(decode (d.estatdespesa,2,inet, 0)) aprovada, 
             SUM(decode (d.estatdespesa,3,inet, 0)) pdteabonada,
             SUM(decode (d.estatdespesa,4,inet, 0)) abonada
        FROM despesavigent d RIGHT JOIN parlament p ON (d.parlament = p.id AND d.anyo = p_any)
       GROUP BY p.id, p.nom, p.numparlamentaris;
BEGIN
   v_parin := CONCAT('p_any=', p_any);
   
   FOR reg IN consulta(p_any)
   LOOP
      v_contador := v_contador + 1;
      v_consulta.EXTEND;
      v_consulta(v_contador) := obj_estat_comptable (reg.nom, reg.numparlamentaris, reg.pdteaprovada,
                                    reg.aprovada, reg.pdteabonada, reg.abonada);
   END LOOP;
   p_log (v_nomproc, v_parin, RSP);
   RETURN v_consulta;
EXCEPTION
   WHEN OTHERS
   THEN
      RSP :=  CONCAT(PK_ERRORS.ERR_NOTRACTAT, (TO_CHAR(SQLCODE) || ' '|| SUBSTR(SQLERRM,1,400)));
      p_log (v_nomproc, v_parin, RSP);
      RETURN NULL;   
END estat_comptable;
/
