/**
*<p>Llistat dels parlamentaris amb la despesa directa que han fet donat un parlament 
* i any en concret ordenat  de forma descendent per la suma de la despesa. Aquesta 
*informa el nom i llinatges del parlamentari, el partit polític actual al que està 
*associat i la suma de totes les seves despeses</p>
*@author Toni Torres
*
*@param  p_parlament    Codi identificatiu intern del parlament
*@param  p_any          Any
*@return tab_parlamentari_desp_directa
*/
CREATE OR REPLACE FUNCTION parlamentari_despesa_directa (
   p_parlament       despesa.parlament%TYPE,
   p_any             despesa.anyo%TYPE
)
   RETURN tab_parlamentari_desp_directa
IS
   v_nomproc	      logs.nomproc%TYPE := 'parlamentari_despesa_directa';
   v_parin		      logs.parin%TYPE;
   RSP               logs.rsp%TYPE := 'OK';
   
   v_consulta     tab_parlamentari_desp_directa := tab_parlamentari_desp_directa();
   v_contador     NUMBER := 0;
   
   CURSOR consulta (p_parlament NUMBER, p_any NUMBER) IS
      SELECT pl.nom ||' ' ||  pl.cognoms nomparlamentari, 
               pp.nom nompartit, sum(d.inet) TOTAL
         FROM despesavigent d INNER JOIN parlamentari pl ON (d.parlamentari = pl.id)
               INNER JOIN partit pp on (pl.partit=pp.id)
         WHERE d.parlament = p_parlament
         AND d.anyo = p_any
         AND d.origendespesa = 2
         GROUP BY pl.id, pl.nom, pl.cognoms, pp.nom
         ORDER BY TOTAL DESC;
BEGIN
   v_parin := CONCAT('p_parlament=', p_parlament);
   v_parin := v_parin || CONCAT('; p_any=', p_any);
   
   FOR reg IN consulta (p_parlament, p_any)
   LOOP
      v_contador := v_contador + 1;         
      v_consulta.extend;
      v_consulta(v_contador) := obj_parlamentari_desp_directa (reg.nomparlamentari, reg.nompartit, reg.total);
   END LOOP;
   p_log (v_nomproc, v_parin, RSP);
   RETURN v_consulta;
EXCEPTION
   WHEN OTHERS
   THEN
      RSP :=  CONCAT(PK_ERRORS.ERR_NOTRACTAT, (TO_CHAR(SQLCODE) || ' '|| SUBSTR(SQLERRM,1,400)));
      p_log (v_nomproc, v_parin, RSP);
      RETURN NULL;   
END;
/
