/**
* <p>Llistat de parlamentaris que superen la mitja de tots el parlamentaris associats 
* al parlament en un any en concret. Aquesta informa el nom complet del parlamentari, 
* partit polític actual del parlamentari, la despesa generada i el percentatge en que 
* supera la mitja del parlament.</p>
*@author Toni Torres
*
*@param p_param     Codi identificatiu del parlament
*@param p_any       Any
*@return tab_parlamentari_supera_mitja
*/
CREATE OR REPLACE FUNCTION parlamentari_supera_mitja (
   p_parlament       despesa.parlament%TYPE,
   p_any             despesa.anyo%TYPE
)
   RETURN tab_parlamentari_supera_mitja
IS
   v_nomproc	      logs.nomproc%TYPE := 'parlamentari_supera_mitja';
   v_parin		      logs.parin%TYPE;
   RSP               logs.rsp%TYPE := 'OK';
   
   v_contador     NUMBER := 0;
   v_consulta     tab_parlamentari_supera_mitja := tab_parlamentari_supera_mitja ();
   
   CURSOR consulta (p_parlament NUMBER, p_any NUMBER) IS
      SELECT pl.nom || ' ' || pl.cognoms NOM, pt.nom PARTIT, SUM(d.inet) TOTAL, (SUM(d.inet)/mitja.mitja -1 )*100 SUPERA
        FROM despesavigent d INNER JOIN parlamentari pl ON (d.parlamentari = pl.id)
             INNER JOIN partit pt ON  (pl.partit = pt.id)
             INNER JOIN (SELECT parlament, anyo, AVG(inet) mitja 
                           FROM despesavigent
                          WHERE origendespesa = 2
                          GROUP BY parlament, anyo) mitja ON (d.parlament=mitja.parlament AND d.anyo=mitja.anyo)
       WHERE d.parlament = p_parlament
         AND d.origendespesa = 2
         AND d.anyo = p_any
      HAVING SUM(d.inet) > (SELECT AVG(inet) FROM despesavigent
                             WHERE parlament = p_parlament
                               AND anyo = p_any
                               AND origendespesa = 2)
       GROUP BY pl.id, pl.nom || ' ' || pl.cognoms, pt.nom, mitja.mitja;
BEGIN
   v_parin := CONCAT('p_parlament=', p_parlament);
   v_parin := v_parin || CONCAT('; p_any=', p_any);
   
   FOR reg IN consulta(p_parlament, p_any)
   LOOP
      v_contador := v_contador + 1;
      v_consulta.EXTEND;
      v_consulta(v_contador) := obj_parlamentari_supera_mitja (reg.nom, reg.partit, reg.total, reg.supera);
   END LOOP;
   p_log (v_nomproc, v_parin, RSP);
   RETURN v_consulta;
EXCEPTION
   WHEN OTHERS
   THEN
      RSP :=  CONCAT(PK_ERRORS.ERR_NOTRACTAT, (TO_CHAR(SQLCODE) || ' '|| SUBSTR(SQLERRM,1,400)));
      p_log (v_nomproc, v_parin, RSP);
      RETURN NULL;
END parlamentari_supera_mitja;
/
