CREATE OR REPLACE PACKAGE PK_ABM 
AS
   
   /**
	* <p>
	* <b>Project:</b>         Control Despesa<br/>
	* <b>Description:</b>     Paquet que implemta el mantenimient de les taules parlament, parlamentari, partit i despesa<br/>
	* <b>DB impact:</b>       SI<br/>
	* <b>Commit inside:</b>   SI<br/>
	* <b>Rollback inside:</b> SI<br/>
	* <b>Autonomous Transaction inside:</b> NO<br/>
	* </p>
	* @author Toni Torres
	* @headcom
	*/
	
	/**
   * Alta parlament.
   * <p>Dona d'alta un parlament. Abans de donar d'alta el parlament comprova que no
   * existeix cap altre parlament amb el mateix codi identificatiu i tampoc un altre
   * parlament en el mateix pais i regió.</p>
   * <p>El document identificatiu sempre es guarda en majúscules</p>
   *
	* @param p_document           VARCHAR2. OBLIGATORI. Codi identificatiu únic de la persona jurídica (CIF, ..)
	* @param p_nom                VARCHAR2. OBLIGATORI. Nom del parlament
   * @param p_pais               VARCHAR2. OBLIGATORI. Codi de pais al que pertany el parlament.
   * @param p_regio              VARCHAR2. Codi de regió a la que pertany el parlament
	* @param p_direccio           VARCHAR2. OBLIGATORI. Direcció de la seu central del parlament
	* @param p_telefon            VARCHAR2. OBLIGATORI. Número de telèfon
	* @param p_web                VARCHAR2. Pàgina Web
	* @param p_usuari             VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
	* @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS
   * @throws                     ERR_PAIS                ERROR: CODI DE PAIS NO TROBAT
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI
   * @throws                     ERR_DUP_PARLAMENT       ERROR: JA EXISTEIX UN PARLAMENT AMB AQUEST DOCUMENT
   * @throws                     ERR_REGIO               ERROR: REGIO NO TROBADA
   * @throws                     ERR_PAISREGIO_PARLAMENT ERROR: JA EXISTEIX UN PARLAMENT ASSOCIAT AL PAIS I REGIO
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
	*/
	PROCEDURE alta_parlament (
		p_document     IN	   parlament.document%TYPE,   
		p_nom          IN	   parlament.nom%TYPE,        
		p_pais      	IN    parlament.pais%TYPE,
      p_regio        IN    parlament.regio%TYPE,       
		p_direccio  	IN    parlament.direccio%TYPE,   
		p_telefon   	IN    parlament.telefon%TYPE,    
		p_web       	IN	   parlament.web%TYPE,        
		p_usuari		   IN	   parlament.usualta%TYPE,    
		RSP				OUT   VARCHAR2
	);
	
	
   
   /**
   * Modifica parlament
   * <p>Modifica les dades d'un parlament a partir del codi identificatiu intern del parlament.</p>
   * <p>Comprova que no existeixi un altre parlament amb el mateix codi de document, que no existeixi 
   * un altre parlament amb el mateix país i regió i que le parlament estigui operatiu </p>
   * <p>El document identificatiu sempre es guarda en majúscules</p>
   *
   * @param p_id                 NUMBER. OBLIGATORI. Codi intern identificatiu del parlament
   * @param p_document           VARCHAR2. OBLIGATORI. Codi identificatiu únic de la persona jurídica (CIF, ..)
	* @param p_nom                VARCHAR2. OBLIGATORI. Nom del parlament
   * @param p_pais               VARCHAR2. OBLIGATORI. Codi de pais al que pertany el parlament.
   * @param p_regio              VARCHAR2. Codi de regió a la que pertany el parlament
	* @param p_direccio           VARCHAR2. OBLIGATORI. Direcció de la seu central del parlament
	* @param p_telefon            VARCHAR2. OBLIGATORI. Número de telèfon
	* @param p_web                VARCHAR2. Pàgina Web
	* @param p_usuari             VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI
   * @throws                     ERR_PAIS                ERROR: CODI DE PAIS NO TROBAT
   * @throws                     ERR_DUP_PARLAMENT       ERROR: JA EXISTEIX UN PARLAMENT AMB AQUEST DOCUMENT
   * @throws                     ERR_REGIO               ERROR: REGIO NO TROBADA
   * @throws                     ERR_PAISREGIO_PARLAMENT ERROR: JA EXISTEIX UN PARLAMENT ASSOCIAT AL PAIS I REGIO
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */
	PROCEDURE modif_parlament (
		p_id			   IN	   parlament.id%TYPE,
		p_document		IN	   parlament.document%TYPE,
		p_nom       	IN    parlament.nom%TYPE,
		p_pais      	IN    parlament.pais%TYPE,
      p_regio        IN    parlament.regio%TYPE,
		p_direccio  	IN    parlament.direccio%TYPE,
		p_telefon   	IN    parlament.telefon%TYPE,
		p_web       	IN	   parlament.web%TYPE,
		p_usuari		   IN	   parlament.usumod%TYPE,
		RSP				OUT   VARCHAR2
	);
	
   
   /**
   * Baixa parlament
   * <p>Dona de baixa un parlament a partir del codi identificatiu intern del parlament.</p> 
   * <p>Abans de realitzar la baixa comprova que el parlament estigui operatiu i que no tengui 
   * parlamentaris associats operatius.</p>
   *
   * @param p_id                 NUMBER. OBLIGATORI. Codi intern identificatiu del parlament
   * @param p_usuari             VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI
   * @throws                     ERR_PARLA_PARLAMENT     ERROR: HI HA PARLAMENTARIS ACTIUS ASSOCIATS AL PARLAMENT
   * @throws                     ERR_BAIXA_PARLAMENT     ERROR: EL PARLAMENT NO EXISTEIX O ESTA DONAT DE BAIXA
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */
	PROCEDURE baixa_parlament (
		p_id			   IN	   parlament.id%TYPE,
		p_usuari		   IN	   parlament.usubaixa%TYPE,
		RSP				OUT	VARCHAR2
	);
	
   
   
   /** 
   * Reactivar parlament
   * <p>Reactiva un parlament donat de baixa. Abans de fer les modificacions comprova 
   * existeixi el parlament i que estigui donat de baixa.
   *
   * @param p_id                 NUMBER. OBLIGATORI. Codi intern indentificatiu del parlament
   * @param p_usuari             VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI
   * @throws                     ERR_PARLAMENT_OPERATIU  ERROR: EL PARLAMENT NO ESTA DONAT DE BAIXA
   * @throws                     ERR_PARLAMENT_NEXIST    ERROR: EL PARLAMENT NO EXISTEIX O ESTA DONAT DE BAIXA
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */
   PROCEDURE react_parlament (
      p_id           IN    parlament.id%TYPE,
      p_usuari       IN    parlament.usumod%TYPE,
      RSP            OUT   VARCHAR2
   );
   
   /**
   * Alta Partit Polític
   * <p>Dona d'alta un partit politic. Abans de realitzar l'alta comprova que no hi hagi un altre 
   * partit amb el mateix documet identificatiu.</p>
   * <p>El document identificatiu sempre es guarda en majúscules.</p>
   *
   * @param p_document           VARCHAR2. OBLIGATORI. Codi identificatiu únic de la persona jurídica (CIF, ..)
   * @param p_nom                VARCHAR2. OBLIGATORI. Nom del partit
   * @param p_usuari             VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI
   * @throws                     ERR_DUP_PARTIT          ERROR: JA EXISTEIX UN PARTIT POLITIC AMB AQUEST DOCUMENT
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */
	PROCEDURE alta_partit (
		p_document		IN	   partit.document%TYPE,
		p_nom			   IN	   partit.nom%TYPE,
		p_usuari		   IN    partit.usualta%TYPE,
		RSP				OUT   VARCHAR2
	);
	
   /**
   * Modifica Partit Polític
   * <p>Modifica les dades d'un partit polític a partir del codi identificatiu intern del partit.</p>
   * <p>Abans de realitzar l'operació comprova que no existeixi un altre partit amb el mateix
   * document identificatiu.</p>
   * <p>El document identificatiu sempre es guarda en majúscules</p>
   *
   * @param p_id                 NUMBER. OBLIGATORI. Codi intern identificatiu
   * @param p_document           VARCHAR2. OBLIGATORI. Codi identificatiu únic de la persona jurídica (CIF, ..)
   * @param p_nom                VARCHAR2. OBLIGATORI. Nom del partit
   * @param p_usuari             VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI
   * @throws                     ERR_DUP_PARTIT          ERROR: JA EXISTEIX UN PARTIT POLITIC AMB AQUEST DOCUMENT
   * @throws                     ERR_BAIXA_PARTIT        ERROR: EL PATIT NO EXISTEIX ESTA DONAT DE BAIXA
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */
	PROCEDURE modif_partit (
		p_id			   IN	   partit.id%TYPE,
		p_document		IN	   partit.document%TYPE,
		p_nom			   IN	   partit.nom%TYPE,
		p_usuari		   IN	   partit.usumod%TYPE,
		RSP				OUT   VARCHAR2
	);
	
   /**
   * Baixa Partit Polític
   * Dona de baixa un partit a partir del codi indentificatiu intern del partit.</p>
   * <p>Abans de realitzar l'operació comprova que el partit estigui opeatiu i que no hi hagi parlamentaris actius 
   * associats al partit.</p>
   *
   * @param p_id                 NUMBER. OBLIGATORI. Codi intern identificatiu
   * @param p_usuari             VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI
   * @throws                     ERR_PARLA_PARTIT        ERROR: HI HA PARLAMENTARIS ACTIUS ASSOCIATS AL PARTIT
   * @throws                     ERR_BAIXA_PARTIT        ERROR: EL PATIT NO EXISTEIX ESTA DONAT DE BAIXA
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */
	PROCEDURE baixa_partit (
		p_id			   IN	   partit.id%TYPE,
		p_usuari		   IN	   partit.usubaixa%TYPE,
		RSP				OUT   VARCHAR2
	);
	
   
   /** 
   * Reactivar partit
   * <p>Reactiva un partit polític donat de baixa. Abans de fer les modificacions comprova 
   * existeixi el partit polític i que estigui donat de baixa.</p>
   * @param p_id                 NUMBER. OBLIGATORI. Codi intern indentificatiu del partit politic
   * @param p_usuari             VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L''USUARI
   * @throws                     ERR_PARTIT_NEXIST       ERROR: EL PARTIT NO EXISTEIX
   * @throws                     ERR_PARTIT_OPERATIU     ERROR: EL PARTIT NO ESTA DONAT DE BAIXA
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */
   PROCEDURE react_partit (
      p_id           IN    partit.id%TYPE,
      p_usuari       IN    partit.usumod%TYPE,
      RSP            OUT   VARCHAR2
   );   
   
   /**
   * Alta Parlamentari
   * Dona d'alta un parlamentari. Abans de realitzar l'alta comprova que no exiteixi un altre 
   * parlamentari amb el mateix document identificatiu o amb el maiteix 
   * número identificatiu de parlamentari.</p>
   * <p>El parlamanet i partit al qual s'associa el parlamentari han d'estar
   * operatius.</p>
   *
   * @param p_document           VARCHAR2. OBLIGATORI. Codi identificatiu únic de la persona física (NIF, ..)
   * @param p_parlament          NUMBER. OBLIGATORI. Codi identificatiu intern del parlament
   * @param p_partit             VARCHAR2. OBLIGATORI. Codi identificatiu intern del partit
   * @param p_nom                VARCHAR2. OBLIGATORI. Nom del parlamentari
   * @param p_cognoms            VARCHAR2. OBLIGATORI. Llinatges del parlamentari
   * @param p_numIdentificacio   VARCHAR2. OBLIGATORI. Número idnetificatiu del parlamentari
   * @param p_numtargeta         VARCHAR2. OBLIGATORI. Número de la targeta de crèdit associada al parlamentari
   * @param p_usuari             VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws               ERR_PARAMS_NULL               ERROR: HI HA CAMPS NO INFORMATS
   * @throws               ERR_USER                      ERROR: FALTA INFORMAR L'USUARI
   * @throws               ERR_BAIXA_PARLAMENT           ERROR: EL PARLAMENT NO EXISTEIX O ESTA DONAT DE BAIXA
   * @throws               ERR_BAIXA_PARTIT              ERROR: EL PATIT NO EXISTEIX ESTA DONAT DE BAIXA
   * @throws               ERR_DUP_PARL                  ERROR: JA EXISTEIX UN PARLAMENTARI AMB AQUESTA DOCUMENT
   * @throws               ERR_DUP_IDENTPARL             ERROR: JA EXISTEIX UN PARLAMENTARI AMB AQUESTA IDENTIFICACIÓ
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */
	PROCEDURE alta_parlamentari (
		p_document		IN	   parlamentari.document%TYPE,
		p_parlament 	IN	   parlamentari.parlament%TYPE,
		p_partit		   IN	   parlamentari.partit%TYPE,
		p_nom       	IN	   parlamentari.nom%TYPE,
		p_cognoms   	IN	   parlamentari.cognoms%TYPE,
		p_numIdentificacio 	IN	parlamentari.numidentificacio%TYPE,
		p_numTargeta	IN	   parlamentari.numtargeta%TYPE,
		p_usuari		   IN	   parlamentari.usualta%TYPE,
		RSP				OUT	VARCHAR2

	);
	
   /**
   * Modifica parlamentari.
   * <p>Modifica les dades d'un parlamentari a partir del codi identificatiu inten del parlamentari.</p>
   * <p>A partir del codi identificatiu intern del parlamentari modifica 
   * les seves dades.</p>
   * <p>Abans de realitzar les modificacions comprova que el parlament
   * i el partit estan operatius, que no existeix un altre parlamentari
   * amb el mateix document ni amb el mateix número identificatiu.</p>
   *
   * @param p_id                 NUMBER. OBLIGATORI. Codi identificatiu intern del parlamnetari
   * @param p_document           VARCHAR2. OBLIGATORI. Codi identificatiu únic de la persona (NIF, ....)
   * @param p_parlament          NUMBER. OBLIGATORI, Codi identificatiu intern del parlament
   * @param p_partit             NUMBER. OBLIGATORI. Codi identificatiu intern del partit
   * @param p_nom                VARCHAR2. OBLIGATORI. Nom del parlamentari
   * @param p_cognoms            VARCHAR2. OBLIGATORI. Llinatges del parlamentari
   * @param p_numindentificacio  VARCHAR2. OBLIGATORI. Número identificatiu del parlamentari
   * @param p_numtargeta         VARCHAR2. Número de la targeta de crèdit associada al parlamentari
   * @param p_usuari             VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI
   * @throws                     ERR_BAIXA_PARLAMENT     ERROR: EL PARLAMENT NO EXISTEIX O ESTA DONAT DE BAIXA
   * @throws                     ERR_BAIXA_PARTIT        ERROR: EL PATIT NO EXISTEIX ESTA DONAT DE BAIXA
   * @throws                     ERR_DUP_PARL            ERROR: JA EXISTEIX UN PARLAMENTARI AMB AQUESTA DOCUMENT 
   * @throws                     ERR_DUP_IDENTPARL       ERROR: JA EXISTEIX UN PARLAMENTARI AMB AQUESTA IDENTIFICACIÓ   
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */
	PROCEDURE modif_parlamentari (
		p_id			   IN	   parlamentari.id%TYPE,
		p_document		IN	   parlamentari.document%TYPE,
		p_parlament 	IN	   parlamentari.parlament%TYPE,
		p_partit		   IN	   parlamentari.partit%TYPE,
		p_nom       	IN	   parlamentari.nom%TYPE,
		p_cognoms   	IN	   parlamentari.cognoms%TYPE,
		p_numIdentificacio 	IN	parlamentari.numidentificacio%TYPE,
		p_numTargeta	IN	   parlamentari.numtargeta%TYPE,
		p_usuari		   IN	   parlamentari.usumod%TYPE,
		RSP				OUT	VARCHAR2

	);
	
   /**
   * Baixa parlamentari
   * <p>Dona de baixa un parlamentari a partir del codi identificatiu intern del parlamentari.</p>
   * <p>Abans de realitzar la baixa comprova que el parlamentari estigui operatiu.</p>
   *
   * @param p_id                 NUMBER. OBLIGATORI. Codi identificatiu intern del parlamentari
   * @param p_usuari             VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS  
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI        
   * @throws                     ERR_BAIXA_PARL          ERROR: EL PARLAMENTARI ESTA DONAT DE BAIXA
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */
	PROCEDURE baixa_parlamentari (
		p_id		      IN		parlamentari.id%TYPE,
		p_usuari	      IN		parlamentari.usubaixa%TYPE,
		RSP			   OUT	VARCHAR2
	);
	
   
   /** 
   * Reactivar parlamentari
   * <p>Reactiva un parlamentari donat de baixa. Abans de fer les modificacions 
   * comprova que existeixi el parlamentari, que estigui donat de baixa i que tan
   * el partit polític com el parlament estiguin operatius</p>
   * @param p_id                 NUMBER. OBLIGATORI. Codi intern indentificatiu del parlamentari
   * @param p_parlament          NUMBER. OBLIGATORI. Codi identificatiu intern del parlament
   * @param p_partit             NUMBER. OBLIGATORI. Codi identificatiu intern del partit
   * @param p_usuari             VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI     
   * @throws                     ERR_PARLA_OPERATIU      ERROR: EL PARLAMENTARI NO ESTA DONAT DE BAIXA
   * @throws                     ERR_PARLA_NEXIST        ERROR: EL PARLAMENTARI NO EXISTEIX
   * @throws                     ERR_PARLAMENT_NOPERATIU ERROR: EL PARLAMENT NO ESTA ACTIU
   * @throws                     ERR_PARTIT_NOPERATIU    ERROR: EL PARTIT NO ESTA ACTIU
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */
   PROCEDURE react_parlamentari (
      p_id           IN    parlamentari.id%TYPE,
      p_parlament    IN    parlamentari.parlament%TYPE,
      p_partit       IN    parlamentari.partit%TYPE,
      p_usuari       IN    parlamentari.usumod%TYPE,
      RSP            OUT   VARCHAR2
   ); 
   
   /**
   * Alta despesa parlament.
   * <p>Dona d'alta una despesa associada a un parlament</p>
   * <p>Abans de realitzar l'alta comprova que el parlament estigui operatiu, que l'import sigui 
   * un número major que zero, que l'iva sigui major o igual a zero.</p>
   * <p>Comprova que el codi de despesa esta associat a despesa de parlament, els valor possibles
   * son a la vista tipusdespesaparlament.</p>
   * <p>Si la forma de pagament és 1 (transferència) comprova que s'ha informat el IBAN, si és 
   * 2 (targeta de crèdit) comprova que s'ha informat el número de targeta de crèdit. En cap 
   * cas es poden informar els dos, IBAN i targeta de crèdit. </p>
   * <p>Els valors possibles de la forma de pagament son a la taula formapagament.</p>
   * <p>Els valors possibles de l'estat de la despesa son a la taula estatdespesa.</p>
   *
   * @param p_codidespesa        NUMBER. OBLIGATORI. Codi de la despesa.  
   * @param p_parlament          NUMBER. OBLIGATORI. Codi identificatiu intern del parlament
   * @param p_data               DATE. OBLIGATORI. Data de la despesa
   * @param p_ibrut              NUMBER. OBLIGATORI. Import de la despesa. p_ibrut > 0
   * @param p_iva                NUMBER. OBLIGATORI. Tipus de iva aplicat. p_iva >= 0
   * @param p_descripcio         VARCHAR2. OBLIGATORI. Descripció de la despesa  
   * @param p_justificacio       VARCHAR2. OBLIGATORI. Justificació de la despesa
   * @param p_urldocument        VARCAHR2. URL dels documents associats a la despesa
   * @param p_formapagament      NUMBER. OBLIGATORI. Forma de pagament de la depesa. Veure taula FormaPagament
   * @param p_estatdespesa       NUMBER. OBLIGATORI. Estat de la despesa. Veure taula EstatDespesa
   * @param p_iban               VARCHAR2. OBLIGATORI si p_formapagament=1. Número IBAN de la transferència
   * @param p_numtargeta         VARCHAR2. OBLIGATORI si p_formapagament=2. Numero de la targeta de crèdit
   * @param p_usuari		         VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS  
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI
   * @throws                     ERR_BAIXA_PARLAMENT     ERROR: EL PARLAMENT NO EXISTEIX O ESTA DONAT DE BAIXA
   * @throws                     ERR_CODI_DESPESA        ERROR: DESPESA NO TROBADA
   * @throws                     ERR_ESTAT_DESPESA       ERROR: ESTAT DE LA DESPESA INCORRECTA
   * @throws                     ERR_FORMA_PAGAMENT      ERROR: FORMA DE PAGAMENT DE LA DESPESA
   * @throws                     ERR_IBAN                ERROR: FALTA EL NUMERO IBAN DE LA TRANSFERÈNCIA
   * @throws                     ERR_CREDITCARD          ERROR: FALTA EL NUMERO DE LA TARGETA DE CRÈDIT
   * @throws                     ERR_IBAN_CREDITCARD     ERROR: IBAN O TARGETA DE CREDIT
   * @throws                     ERR_IBRUT               ERROR: L'IMPORT HA DE SER MÉS GRAN QUE 0
   * @throws                     ERR_IVA                 ERROR: L'IVA HA DE SER MÉS GRAN O IGUAL QUE 0
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */
	PROCEDURE alta_despesa_parlament (
		p_codidespesa   IN	despesa.codidespesa%TYPE,
		p_parlament     IN	despesa.parlament%TYPE,
		p_data          IN	despesa.data%TYPE,
		p_ibrut         IN	despesa.ibrut%TYPE,
		p_iva           IN	despesa.iva%TYPE,
		p_descripcio    IN	despesa.descripcio%TYPE,
		p_justificacio  IN	despesa.justificacio%TYPE,
		p_urldocument   IN	despesa.urldocument%TYPE,
		p_formapagament IN	despesa.formapagament%TYPE,
		p_estatdespesa  IN	despesa.estatdespesa%TYPE,
      p_iban          IN   despesa.iban%TYPE,
      p_numtargeta    IN   despesa.numtargeta%TYPE,
		p_usuari		    IN	despesa.usualta%TYPE,
		RSP				 OUT	VARCHAR2
	);

   /**
   * Modifica despesa d'un parlament   
   * <p>Modifica les dades d'una despesa feta per un parlament a partir del codi identificatiu intern
   * de la despesa.</p>
   * <p>Abans de realitzar les modificacions comprova que l'import sigui un número major que zero,
   * que l'iva sigui major o igual a zero.</p>
   * <p>Comprova que el codi de despesa esta associat a despesa de parlament, els valor possibles
   * son a la vista tipusdespesaparlament.</p>
   * <p>Si la forma de pagament és 1 (transferència) comprova que s'ha informat el IBAN, si és 
   * 2 (targeta de crèdit) comprova que s'ha informat el número de targeta de crèdit. En cap 
   * cas es poden informar els dos, IBAN i targeta de crèdit.</p> 
   * <p>Els valors possibles de la forma de pagament son a la taula formapagament.</p>
   * <p>Els valors possibles de l'estat de la despesa son a la taula estatdespesa.</p>
   *
   * @param p_id                 NUMBER. OBLIGATORI. Codi identificatiu intern de la despesa.
   * @param p_codidespesa        NUMBER. OBLIGATORI. Codi de la despesa.  
   * @param p_data               DATE. OBLIGATORI. Data de la despesa
   * @param p_ibrut              NUMBER. OBLIGATORI. Import de la despesa. p_ibrut > 0
   * @param p_iva                NUMBER. OBLIGATORI. Tipus de iva aplicat. p_iva >= 0
   * @param p_descripcio         VARCHAR2. OBLIGATORI. Descripció de la despesa  
   * @param p_justificacio       VARCHAR2. OBLIGATORI. Justificació de la despesa
   * @param p_urldocument        VARCAHR2. URL dels documents associats a la despesa
   * @param p_formapagament      NUMBER. OBLIGATORI. Forma de pagament de la depesa. Veure taula FormaPagament
   * @param p_estatdespesa       NUMBER. OBLIGATORI. Estat de la despesa. Veure taula EstatDespesa
   * @param p_iban               VARCHAR2. OBLIGATORI si p_formapagament=1. Número IBAN de la transferència
   * @param p_numtargeta         VARCHAR2. OBLIGATORI si p_formapagament=2. Numero de la targeta de crèdit
   * @param p_usuari		         VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS  
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI
   * @throws                     ERR_CODI_DESPESA        ERROR: DESPESA NO TROBADA
   * @throws                     ERR_ESTAT_DESPESA       ERROR: ESTAT DE LA DESPESA INCORRECTA
   * @throws                     ERR_FORMA_PAGAMENT      ERROR: FORMA DE PAGAMENT DE LA DESPESA
   * @throws                     ERR_IBAN                ERROR: FALTA EL NUMERO IBAN DE LA TRANSFERÈNCIA
   * @throws                     ERR_CREDITCARD          ERROR: FALTA EL NUMERO DE LA TARGETA DE CRÈDIT
   * @throws                     ERR_IBAN_CREDITCARD     ERROR: IBAN O TARGETA DE CREDIT
   * @throws                     ERR_IBRUT               ERROR: L'IMPORT HA DE SER MÉS GRAN QUE 0
   * @throws                     ERR_IVA                 ERROR: L'IVA HA DE SER MÉS GRAN O IGUAL QUE 0
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */	
	PROCEDURE modif_despesa_parlament (
		p_id			    IN	despesa.id%TYPE,
		p_codidespesa	 IN	despesa.codidespesa%TYPE,
		p_data          IN	despesa.data%TYPE,
		p_ibrut         IN	despesa.ibrut%TYPE,
		p_iva           IN	despesa.iva%TYPE,
		p_descripcio    IN	despesa.descripcio%TYPE,
		p_justificacio  IN	despesa.justificacio%TYPE,
		p_urldocument   IN	despesa.urldocument%TYPE,
		p_formapagament IN	despesa.formapagament%TYPE,
		p_estatdespesa  IN	despesa.estatdespesa%TYPE,
      p_iban          IN    despesa.iban%TYPE,
      p_numtargeta    IN    despesa.numtargeta%TYPE,
		p_usuari		    IN   despesa.usumod%TYPE,
		RSP				 OUT	VARCHAR2
	);

   /**
   * Baixa despesa
   * <p>Dona de baixa una despesa a partir del codi indentificatiu intern de la despesa
   * independement que la despesa sigui d'un parlament o d'un parlamentari.</p>
   *
   * @param p_id                 NUMBER. OBLIGATORI. Codi identificatiu intern de la despesa
   * @param p_usuari             VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI
   * @throws                     ERR_BAIXA_DESPESA       ERROR: LA DESPESA JA ESTA DONADA DE BAIXA
   * @throws                                             ERROR NO TRACTAT: codiError + literalError
   */
	PROCEDURE baixa_despesa (
		p_id			   IN	   despesa.id%TYPE,
		p_usuari		   IN	   despesa.usubaixa%TYPE,
		RSP				OUT	VARCHAR2
	);

   /**
   * Alta despesa parlamentari
   * <p>Dona d'alta una despesa associada a un parlamentari. Abans de realitzar l'alta
   * comprova que el parlament i partit polític associats al parlamentari estiguin operatius,
   * que el parlamentari estigui operatiu, que l'import sigui un número major que zero, 
   * que l'iva sigui major o igual a zero.</p> 
   * <p>Comprova que el codi de despesa esta associat a despesa de parlamentari, els valor possibles
   * son a la vista tipusdespesaparlamentari.</p>
   * <p>Si la forma de pagament és 1 (transferència) comprova que s'ha informat el IBAN, si és 
   * 2 (targeta de crèdit) comprova que s'ha informat el número de targeta de crèdit. En cap 
   * cas es poden informar els dos, IBAN i targeta de crèdit.</p> 
   * <p>Els valors possibles de la forma de pagament son a la taula formapagament.</p>
   * <p>Els valors possibles de l'estat de la despesa son a la taula estatdespesa.</p>
   *
   * @param p_codidespesa        NUMBER. OBLIGATORI. Codi de la despesa.  
   * @param p_parlamentari       NUMBER. OBLIGATORI. Codi identificatiu intern del parlamentari
   * @param p_data               DATE. OBLIGATORI. Data de la despesa
   * @param p_ibrut              NUMBER. OBLIGATORI. Import de la despesa. p_ibrut > 0
   * @param p_iva                NUMBER. OBLIGATORI. Tipus de iva aplicat. p_iva >= 0
   * @param p_descripcio         VARCHAR2. OBLIGATORI. Descripció de la despesa  
   * @param p_justificacio       VARCHAR2. OBLIGATORI. Justificació de la despesa
   * @param p_urldocument        VARCAHR2. URL dels documents associats a la despesa
   * @param p_formapagament      NUMBER. OBLIGATORI. Forma de pagament de la depesa. Veure taula FormaPagament
   * @param p_estatdespesa       NUMBER. OBLIGATORI. Estat de la despesa. Veure taula EstatDespesa
   * @param p_iban               VARCHAR2. OBLIGATORI si p_formapagament=1. Número IBAN de la transferència
   * @param p_numtargeta         VARCHAR2. OBLIGATORI si p_formapagament=2. Numero de la targeta de crèdit
   * @param p_empresa            VARCHAR2. Dades de l'empresa de la despesa.
   * @param p_usuari		         VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS  
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI
   * @throws                     ERR_ESTAT_DESPESA       ERROR: ESTAT DE LA DESPESA INCORRECTA
   * @throws                     ERR_CODI_DESPESA        ERROR: DESPESA NO TROBADA
   * @throws                     ERR_BAIXA_PARLAMENT     ERROR: EL PARLAMENT NO EXISTEIX O ESTA DONAT DE BAIXA
   * @throws                     ERR_BAIXA_PARTIT        ERROR: EL PATIT NO EXISTEIX O ESTA DONAT DE BAIXA
   * @throws                     ERR_BAIXA_PARL          ERROR: EL PARLAMENTARI ESTA DONAT DE BAIXA
   * @throws                     ERR_IBAN                ERROR: FALTA EL NUMERO IBAN DE LA TRANSFERÈNCIA
   * @throws                     ERR_CREDITCARD          ERROR: FALTA EL NUMERO DE LA TARGETA DE CRÈDIT 
   * @throws                     ERR_IBAN_CREDITCARD     ERROR: IBAN O TARGETA DE CREDIT
   * @throws                     ERR_IBRUT               ERROR: L'IMPORT HA DE SER MÉS GRAN QUE 0
   * @throws                     ERR_IVA                 ERROR: L'IVA HA DE SER MÉS GRAN O IGUAL QUE 0
   * @throws                     ERR_FORMA_PAGAMENT      ERROR: FORMA DE PAGAMENT DE LA DESPESA
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */
	PROCEDURE alta_despesa_parlamentari (
		p_codidespesa	 IN	despesa.codidespesa%TYPE,
		p_parlamentari	 IN	despesa.parlamentari%TYPE,
		p_data          IN	despesa.data%TYPE,
		p_ibrut         IN	despesa.ibrut%TYPE,
		p_iva           IN	despesa.iva%TYPE,
		p_descripcio    IN	despesa.descripcio%TYPE,
		p_justificacio  IN	despesa.justificacio%TYPE,
		p_urldocument   IN	despesa.urldocument%TYPE,
		p_formapagament IN	despesa.formapagament%TYPE,
		p_estatdespesa  IN	despesa.estatdespesa%TYPE,
      p_iban          IN  despesa.iban%TYPE,
      p_numtargeta    IN  despesa.numtargeta%TYPE,
		p_empresa       IN	despesa.empresa%TYPE,
		p_usuari		    IN	despesa.usualta%TYPE,
		RSP				 OUT	VARCHAR2
	);

   /**
   * Modifcar despesa d'un parlamentari
   * <p>Modifica les dades d'una despesa associada a un parlamentari a partir del codi identificatiu de la despesa.</p>
   * <p>Abans de realitzar les modificacions comprova que l'import sigui un número major que zero,
   * que l'iva sigui major o igual a zero. </p>
   * <p>Comprova que el codi de despesa esta associat a despesa de parlamentari, els valor possibles
   * son a la vista tipusdespesaparlamentari.</p>
   * <p>Si la forma de pagament és 1 (transferència) comprova que s'ha informat el IBAN, si és 
   * 2 (targeta de crèdit) comprova que s'ha informat el número de targeta de crèdit. En cap 
   * cas es poden informar els dos, IBAN i targeta de crèdit.</p>
   * <p>Els valors possibles de la forma de pagament son a la taula formapagament.</p>
   * <p>Els valors possibles de l'estat de la despesa son a la taula estatdespesa.</p>
   *
   * @param p_id                 NUMBER. OBLIGATORI. Codi identificatiu intern de la despesa.
   * @param p_codidespesa        NUMBER. OBLIGATORI. Codi de la despesa.  
   * @param p_data               DATE. OBLIGATORI. Data de la despesa
   * @param p_ibrut              NUMBER. OBLIGATORI. Import de la despesa. p_ibrut > 0
   * @param p_iva                NUMBER. OBLIGATORI. Tipus de iva aplicat. p_iva >= 0
   * @param p_descripcio         VARCHAR2. OBLIGATORI. Descripció de la despesa  
   * @param p_justificacio       VARCHAR2. OBLIGATORI. Justificació de la despesa
   * @param p_urldocument        VARCAHR2. URL dels documents associats a la despesa
   * @param p_formapagament      NUMBER. OBLIGATORI. Forma de pagament de la depesa. Veure taula FormaPagament
   * @param p_estatdespesa       NUMBER. OBLIGATORI. Estat de la despesa. Veure taula EstatDespesa
   * @param p_iban               VARCHAR2. OBLIGATORI si p_formapagament=1. Número IBAN de la transferència
   * @param p_numtargeta         VARCHAR2. OBLIGATORI si p_formapagament=2. Numero de la targeta de crèdit
   * @param p_empresa            VARCHAR2. Dades de l'empresa de la despesa. 
   * @param p_usuari		         VARCHAR2. OBLIGATORI. Usuari que realitza l'operació
   * @param RSP                  Resposta de l'operació
   *                             <ul>"OK" = Procés executat correctament</ul>
   *                             <ul>"ERROR:" = Procés finalitzat amb error i el motiu de l'error</ul>
   *
   * @throws                     ERR_PARAMS_NULL         ERROR: HI HA CAMPS NO INFORMATS  
   * @throws                     ERR_USER                ERROR: FALTA INFORMAR L'USUARI
   * @throws                     ERR_CODI_DESPESA        ERROR: DESPESA NO TROBADA
   * @throws                     ERR_ESTAT_DESPESA       ERROR: ESTAT DE LA DESPESA INCORRECTA
   * @throws                     ERR_FORMA_PAGAMENT      ERROR: FORMA DE PAGAMENT DE LA DESPESA
   * @throws                     ERR_IBAN                ERROR: FALTA EL NUMERO IBAN DE LA TRANSFERÈNCIA
   * @throws                     ERR_CREDITCARD          ERROR: FALTA EL NUMERO DE LA TARGETA DE CRÈDIT
   * @throws                     ERR_IBAN_CREDITCARD     ERROR: IBAN O TARGETA DE CREDIT
   * @throws                     ERR_IBRUT               ERROR: L'IMPORT HA DE SER MÉS GRAN QUE 0
   * @throws                     ERR_IVA                 ERROR: L'IVA HA DE SER MÉS GRAN O IGUAL QUE 0
   * @throws                     ERR_NOTRACTAT           ERROR NO TRACTAT: codiError + literalError
   */		
	PROCEDURE modif_despesa_parlamentari (
		p_id			    IN	despesa.id%TYPE,
		p_codidespesa	 IN	despesa.codidespesa%TYPE,
		p_data          IN	despesa.data%TYPE,
		p_ibrut         IN	despesa.ibrut%TYPE,
		p_iva           IN	despesa.iva%TYPE,
		p_descripcio    IN	despesa.descripcio%TYPE,
		p_justificacio  IN	despesa.justificacio%TYPE,
		p_urldocument   IN	despesa.urldocument%TYPE,
		p_formapagament IN	despesa.formapagament%TYPE,
		p_estatdespesa  IN	despesa.estatdespesa%TYPE,
      p_iban          IN  despesa.iban%TYPE,
      p_numtargeta    IN  despesa.numtargeta%TYPE,
      p_empresa		 IN	despesa.empresa%TYPE,
		p_usuari		    IN	despesa.usualta%TYPE,      
		RSP				 OUT	VARCHAR2
	);
	
END;
/

